@@ -129,6 +129,80 @@ class BarSet(dict):
         return self._df
 
 
+class _Timestamped(object):
+    _tskeys = ('timestamp',)
+
+    def __getattr__(self, key):
+        if key in self._raw:
+            val = self._raw[key]
+            if key in self._tskeys:
+                return pd.Timestamp(val, tz=NY, unit=self._unit)
+            return val
+        return getattr(super(), key)
+
+
+class _NanoTimestamped(_Timestamped):
+    _unit = 'ns'
+
+
+class _MilliTimestamped(_Timestamped):
+    _unit = 'ms'
+
+
+class Agg(_MilliTimestamped, Entity):
+    _tskeys = ('timestamp', 'start', 'end')
+
+
+class Aggs(list):
+    def __init__(self, raw):
+        self._raw = raw
+        super().__init__([
+            Agg(tick) for tick in self.rename_keys()
+        ])
+
+    def _raw_results(self):
+        return self._raw.get('results', [])
+
+    def rename_keys(self):
+        colmap = {
+            "o": "open",
+            "h": "high",
+            "l": "low",
+            "c": "close",
+            "v": "volume",
+            "t": "timestamp",
+        }
+        return [
+            {colmap.get(k, k): v for k, v in tick.items()}
+            for tick in self._raw_results()
+        ]
+
+    @property
+    def df(self):
+        if not hasattr(self, '_df'):
+            columns = ('timestamp', 'open', 'high', 'low', 'close', 'volume')
+            df = pd.DataFrame(
+                self.rename_keys(),
+                columns=columns
+            )
+            df.set_index('timestamp', inplace=True)
+            df.index = pd.to_datetime(
+                df.index.astype('int64'),
+                unit='ms', utc=True
+            ).tz_convert(NY)
+
+            self._df = df
+        return self._df
+
+
+class Trade(_NanoTimestamped, Entity):
+    pass
+
+
+class Quote(_NanoTimestamped, Entity):
+    pass
+
+
 class Clock(Entity):
     def __getattr__(self, key):
         if key in self._raw:
@@ -172,7 +246,7 @@ class PortfolioHistory(Entity):
             df.set_index('timestamp', inplace=True)
             if not df.empty:
                 df.index = pd.to_datetime(
-                    (df.index * 1e6).astype('int64'), utc=True,
+                    (df.index * 1e9).astype('int64'), utc=True,
                 ).tz_convert(NY)
             else:
                 df.index = pd.to_datetime(
@@ -180,3 +254,43 @@ class PortfolioHistory(Entity):
                 )
             self._df = df
         return self._df
+
+
+trade_mapping = {
+    "T": "symbol",
+    "c": "conditions",
+    "x": "exchange",
+    "p": "price",
+    "s": "size",
+    "t": "timestamp"
+}
+
+quote_mapping = {
+    "T": "symbol",
+    "X": "askexchange",
+    "P": "askprice",
+    "S": "asksize",
+    "x": "bidexchange",
+    "p": "bidprice",
+    "s": "bidsize",
+    "c": "conditions",
+    "t": "timestamp"
+}
+
+agg_mapping = {
+    "T": "symbol",
+    "o": "open",
+    "c": "close",
+    "h": "high",
+    "l": "low",
+    "a": "average",
+    "x": "exchange",
+    "v": "volume",
+    "s": "start",
+    "e": "end",
+    "vw": "vwap",
+    "av": "totalvolume",
+
+    # this is extra alias in the client side
+    "t": "timestamp",
+}
